@@ -4,12 +4,13 @@ use strict;
 use warnings;
 
 use base qw/DBIx::Class::ResultSourceProxy/;
-use DBIx::Class::ResultSource::Table;
+__PACKAGE__->load_components(qw/AccessorGroup/);
+
+__PACKAGE__->mk_group_accessors('component_class' => 'table_class');
+__PACKAGE__->table_class('DBIx::Class::ResultSource::Table');
 
 __PACKAGE__->mk_classdata('table_alias'); # FIXME: Doesn't actually do anything yet!
 
-__PACKAGE__->mk_classdata('table_class' => 'DBIx::Class::ResultSource::Table');
-
 =head1 NAME 
 
 DBIx::Class::ResultSourceProxy::Table - provides a classdata table object and method proxies
